//
// JTypist v3.1 - Java typing tutor program for UNIX systems
// Copyright (C) 1999  Simon Baldwin (simonb@sco.com)
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//
// FingerIcon class - implements a stylized finger graphic
//
import java.applet.*;
import java.awt.*;

/**
 * Implements a stylized graphic of a finger.
 */
public class FingerIcon extends Canvas {

	/**
	 * Default unit size of a finger icon.
	 */
	public static int	DEFAULT_SIZE		= 24;

	// the legend shown on the graphic, and the dimensions
	private String		legend		= null;
	private Dimension	pref_size	= null;


	/**
	 * Create a finger icon with the specified legend and unit size.
	 * A null legend creates a blank.
	 */
	public FingerIcon( String legend, int unit_size ) {
		this.legend	= legend;
		this.pref_size	= new Dimension( unit_size, unit_size );
	}

	/**
	 * Create a finger icon with the specified legend.
	 */
	public FingerIcon( String legend ) {
		this( legend, DEFAULT_SIZE );
	}

	/*
	 * Return dimensions.
	 */
	public synchronized Dimension getPreferredSize() {
		return ( pref_size ); }
	public synchronized Dimension getMinimumSize() {
		return ( pref_size ); }

	/**
	 * Paint the complete graphic.
	 */
	public synchronized void paint( Graphics g ) {
		Dimension d = getSize();

		// see if the legend signifies something other than blank
		if ( legend != null ) {

			// create an initial filled box
			g.setColor( getForeground() );
			g.fillOval( 2, 2, d.width - 4, d.height - 4 );

			// put the legend in the centre of the box
			if ( getForeground() != Color.black )
				g.setColor( Color.black );
			else
				g.setColor( Color.white );
			FontMetrics fm	= g.getFontMetrics();
			g.drawString( legend,
				( d.width  - fm.stringWidth( legend )) / 2,
				( d.height + fm.getAscent() ) / 2 );
		}
		else {
			// simply blank the panel to the foreground colour
			g.setColor( getForeground() );
			g.fillOval( 2, 2, d.width - 4, d.height - 4 );
		}
	}

	/**
	 * Re-render the complete graphic if anything about this finger icon
	 * has changed.
	 */
	public synchronized void update( Graphics g ) { paint( g ); }

	/*
	 * Standard get/set methods.
	 */
	public synchronized String get_legend()	{ return ( legend ); }
	public synchronized Color get_colour()	{ return ( getForeground() ); }
	public synchronized void set_legend( String legend ) {
		if ( ! legend.equals( this.legend ) ) {
			this.legend = legend; repaint();
		}
	}
	public synchronized void set_colour( Color colour ) {
		if ( colour != getForeground() ) {
			setForeground( colour ); repaint();
		}
	}


	/**
	 * Class test code.
	 */
	public static void main( String args[] ) {
		System.out.println( "*** CLASS TEST CODE ***" );

		Frame frame = new Frame();
		FingerIcon fingericon = new FingerIcon( "LT" );
		frame.setLayout( new BorderLayout() );
		frame.add( "Center", fingericon );
		frame.pack(); frame.setVisible( true );
		while ( true ) {
			fingericon.set_colour( Color.green );
			try { Thread.sleep( 1000 ); }
			catch( InterruptedException e ) {}
			fingericon.set_colour( Color.black );
			try { Thread.sleep( 1000 ); }
			catch( InterruptedException e ) {}
		}
	}
}
