//
// JTypist v3.1 - Java typing tutor program for UNIX systems
// Copyright (C) 1999  Simon Baldwin (simonb@sco.com)
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
//
// Glyph class - defines the data we hold about a key glyph
//

/**
 * Defines the data we hold about a key glyph.
 */
public class Glyph {

	// for a key glyph we hold the char on the key, the keyboard
	// keycode that it comes from (for the keyboard map window),
	// its shift state (again for the keyboard map window),
	// details about the finger responsible for striking the key, and
	// some notion about what group of keys that glyph is in
	private Character	character;
	private int		keycode;
	private boolean		shifted;
	private Finger		finger;
	private GlyphGroup	group;


	/**
	 * Constructor, mostly used use in building tables.
	 */
	public Glyph( char character, int keycode, boolean shifted,
			Finger finger, GlyphGroup group ) {

		// save the key details
		this.character	= new Character( character );
		this.keycode	= keycode;
		this.shifted	= shifted;
		this.finger	= finger;
		this.group	= group;
	}


	/*
	 * Accessor methods.
	 */
	public Character	get_character()	{ return ( character ); }
	public int		get_keycode()	{ return ( keycode ); }
	public boolean		is_shifted()	{ return ( shifted ); }
	public Finger		get_finger()	{ return ( finger ); }
	public GlyphGroup	get_group()	{ return ( group ); }


	/**
	 * Method to return a reasonable string representation of the
	 * glyph; useful in printouts and statistics screens.
	 */
	public String get_text() {

		// translate \n into Enter, and ' ' to space, otherwise
		// just return "Key 'X'"
		if ( character.charValue() == '\n' )
			return( "Enter" );
		else if ( character.charValue() == ' ' )
			return( "Space" );
		else
			return( "Key '" + character.charValue() + "'" );
	}


	/**
	 * Printout method.
	 */
	public String toString() {
		return ( getClass().getName() + "{character='" + character
				+ "',keycode=" + keycode
				+ ",shifted=" + shifted
				+ ",finger=" + finger
				+ ",group=" + group + "}" );
	}


	/**
	 * Class test code.
	 */
	public static void main ( String args[] ) {
		System.out.println( "*** CLASS TEST CODE ***" );

		System.out.println( new Glyph( 'a', 37, false, Finger.LH_PINKY,
				GlyphGroup.UNSHIFTED_ALPHA ));
		System.out.println( new Glyph( 'Y', 28, true, Finger.RH_INDEX,
				GlyphGroup.SHIFTED_ALPHA ));
		System.out.println( new Glyph( ' ', 64, false, Finger.RH_THUMB,
				GlyphGroup.BASIC ));
	}
}
